Module uim.utils
================
This package contains utility functions for the UIM package.

Sub-modules
-----------
* uim.utils.analyser
* uim.utils.matrix
* uim.utils.statistics
* uim.utils.stroke_resampling